Crate endinero

Crate endinero 

Copyright 2022-2025 DiarioBitcoin.com, Angel Leon

Licensed under the Apache License, Version 2.0 (the “License”); you may not use this file except in compliance with the License. You may obtain a copy of the License at

https://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an “AS IS” BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Functions

dinero_f32
Format f32 input into a spanish money format, max 2 decimal places if amount > 0, up to 17 decimal places for amount < 1. Thousands separator: ., Radix character: ,, Decimals separator:
dinero_f64
Format f64 input into a spanish money format, max 2 decimal places if amount > 0, up to 17 decimal places for amount < 1. Thousands separator: ., Radix character: ,, Decimals separator:
endinero_f32
Customize the separator characters and decimal precision used to format the output of the given f32 number
endinero_f64
Customize the separator characters and decimal precision used to format the output of the given f64 number
money_f32
Format f32 input into a US money format, max 2 decimal places if amount > 0, up to 7 decimal places for amount < 1. Thousands separator: ,, Radix character: ., Decimals separator:
money_f64
Format f64 input into a US money format, max 2 decimal places if amount > 0, up to 17 decimal places for amount < 1. Thousands separator: ,, Radix character: ., Decimals separator: